@@ -2,27 +2,34 @@ from investing_algorithm_framework.utils.version import get_version
 from investing_algorithm_framework.core.context import \
     AlgorithmContextInitializer, AlgorithmContext
 from investing_algorithm_framework.core.portfolio_managers import \
-    AbstractPortfolioManager, PortfolioManager
+    PortfolioManager, BinancePortfolioManager
+from investing_algorithm_framework.core.order_executors import OrderExecutor, \
+    BinanceOrderExecutor
 from investing_algorithm_framework.core.models import OrderSide, Order, \
-    Position, TimeUnit, db, Portfolio
+    Position, TimeUnit, db, Portfolio, OrderType
 from investing_algorithm_framework.app import App
 from investing_algorithm_framework.globals import current_app
+from investing_algorithm_framework.configuration import Config
 from investing_algorithm_framework.views import *
 
-VERSION = (0, 5, 1, 'alpha', 0)
+VERSION = (0, 6, 0, 'alpha', 0)
 
 __all__ = [
     "App",
     'get_version',
-    'AbstractPortfolioManager',
     'PortfolioManager',
+    'BinancePortfolioManager',
     "AlgorithmContextInitializer",
     "Portfolio",
     "OrderSide",
+    "OrderType",
     "Order",
     "Position",
     "TimeUnit",
     "db",
     "current_app",
-    "AlgorithmContext"
+    "AlgorithmContext",
+    "OrderExecutor",
+    'BinanceOrderExecutor',
+    "Config"
 ]
