@@ -8,5 +8,10 @@ DATABASE_TYPE = 'DATABASE_TYPE'
 DATABASE_DIRECTORY_PATH = 'DATABASE_DIRECTORY_PATH'
 DATABASE_URL = 'DATABASE_URL'
 
-
+RESOURCES_DIRECTORY = "RESOURCES_DIRECTORY"
+LOG_LEVEL = 'LOG_LEVEL'
 BASE_DIR = 'BASE_DIR'
+SQLALCHEMY_DATABASE_URI = 'SQLALCHEMY_DATABASE_URI'
+
+
+BINANCE = "BINANCE"
